@@ -1,3 +1,6 @@
+{-# LANGUAGE MultiParamTypeClasses, FunctionalDependencies
+  , TypeSynonymInstances, FlexibleInstances, UndecidableInstances
+  , OverlappingInstances  #-}
 -----------------------------------------------------------
 -- |
 -- Module      :  HDBRec
@@ -22,6 +25,7 @@ module Database.HaskellDB.HDBRec
     , FieldTag(..)
     -- * Record predicates and operations
     , HasField, Select(..), SetField, setField
+    , RecCat(..)
     -- * Showing and reading records
     , ShowLabels(..), ShowRecRow(..), ReadRecRow(..)
     ) where
@@ -58,7 +62,6 @@ _ .=. x = RecCons x
       -> (b -> RecCons f a c)        -- ^ New record
 f # r = let RecCons x _ = f RecNil in RecCons x . r
 
-
 -- | The empty record
 emptyRecord :: Record RecNil
 emptyRecord = id
@@ -81,16 +84,16 @@ instance HasField f r => HasField f (Record r)
 
 class RecCat r1 r2 r3 | r1 r2 -> r3 where
     -- | Concatenates two records.
-    cat :: r1 -> r2 -> r3
+    recCat :: r1 -> r2 -> r3
 
 instance RecCat RecNil r r where
-    cat RecNil r = r
+    recCat ~RecNil r = r
 
 instance RecCat r1 r2 r3 => RecCat (RecCons f a r1) r2 (RecCons f a r3) where
-    cat ~(RecCons x r1) r2 = RecCons x (cat r1 r2)
+    recCat ~(RecCons x r1) r2 = RecCons x (recCat r1 r2)
 
 instance RecCat r1 r2 r3 => RecCat (Record r1) (Record r2) (Record r3) where
-    cat r1 r2 = \n -> cat (r1 n) (r2 n)
+    recCat r1 r2 = \n -> recCat (r1 n) (r2 n)
 
 -- * Field selection
 
