@@ -32,7 +32,7 @@ module Database.HaskellDB.Query (
              , (<<), (<<-)
 	      -- * Function declarations
 	     , project, restrict, table, unique
-	     , union, intersect, divide, minus
+	     , union, unionAll, intersect, divide, minus
 	     , _not, like, _in, cat, _length
 	     , isNull, notNull
 	     , fromNull, fromVal
@@ -41,7 +41,7 @@ module Database.HaskellDB.Query (
 	     , toStr, coerce , select
 	     , count, _sum, _max, _min, avg , literal
 	     , stddev, stddevP, variance, varianceP
-	     , asc, desc, order , top
+	     , asc, desc, order , top, offset
 	     , _case , _default
 	     -- * Internals
 	     , runQuery, runQueryRel, unQuery
@@ -55,6 +55,8 @@ import Database.HaskellDB.PrimQuery
 import Database.HaskellDB.BoundedString
 import Database.HaskellDB.BoundedList
 
+import Control.Applicative
+import Control.Monad
 import System.Time (CalendarTime)
 
 -----------------------------------------------------------
@@ -303,6 +305,10 @@ binrel op (Query q1) (Query q2)
 union :: Query (Rel r) -> Query (Rel r) -> Query (Rel r)
 union           = binrel Union
 
+-- | UNION ALL
+unionAll :: Query (Rel r) -> Query (Rel r) -> Query (Rel r)
+unionAll        = binrel UnionAll
+
 -- | Return all records which are present in both relations.
 intersect :: Query (Rel r) -> Query (Rel r) -> Query (Rel r) 
 intersect       = binrel Intersect
@@ -732,6 +738,10 @@ varianceP x  = aggregate AggrVarP x
 top :: Int -> Query ()
 top n = updatePrimQuery_ (Special (Top n))
 
+-- | Skip the n topmost records.
+offset :: Int -> Query ()
+offset n = updatePrimQuery_ (Special (Offset n))
+
 -----------------------------------------------------------
 -- Ordering results
 -----------------------------------------------------------
@@ -802,6 +812,10 @@ instance Monad Query where
                                             (Query h) = f x
                                         in  (h q1))
 
+instance Applicative Query where
+  pure  = return
+  (<*>) = ap
+
 updatePrimQuery :: (PrimQuery -> PrimQuery) -> Query PrimQuery
 updatePrimQuery f  = Query (\(i,qt) -> (qt,(i,f qt)))
 
